import { prisma } from "@/lib/db"
import { Prisma } from "@prisma/client"

type likeType = Prisma.LikeUncheckedCreateInput

/**
 * Creates like if user has not liked this post.
 * Deletes like if user has liked post already.
 */
export async function putLike(like: likeType): Promise<likeType | undefined> {
    // check if like exists by this user and for this post
    // if exists delete
    // if not create
    try {
        const actualLike = await prisma.like.findFirst({
            where: {
                id: like.id,
                postId: like.postId,
                userId: like.userId
            }
        })

        if (actualLike == null) {
            console.log("like is null")
            throw Error("Message was not liked by this user")
        }

        await prisma.like.delete({
            where: {
                id: actualLike.id
            }
        })

        const msg = await prisma.post.update({
            where: {
                id: like.postId
            },
            data: {
                likeCount: { increment: -1 }
            }
        })

        return undefined;

    } catch {
        const createdLike = await prisma.like.create({
            data: {
                postId: like.postId,
                userId: like.userId
            }
        })

        const updatedMessage = await prisma.post.update({
            where: {
                id: like.postId
            },
            data: {
                likeCount: { increment: 1 }
            }
        })

        return createdLike
    }
}